*###########################################################################################
*### Descriptive statistics - Line graph 

*### PATHS (Put the file path where you downloaded the contents of the zip file)
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
global path 	".../Example2"
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

*### VERSION TRACK
/*
Created by Pavel Luengas
Last update: Nov 20, 2022

Version 1.0 - Nov 20, 2022
   - File created 

Contact me for comments and questions:
pavel@pavellsierra.com

   */

*===========================================================================================

version 14
set more off

*############################################### 
*### Step 1: Open the dataset

/* Content:
Annualized growth rates of three quaterly 
time series (1998q1 - 2013q4)
(1) GDP
(2) Formal employment
(3) Formal employment - Export Manufacturing */

use "$path/Dataset", clear

*############################################### 
*### Step 2: Create the graph

tab yq if yq==153 // 1998q2, I centered each x-axis labels at YearQ2.5

set scheme s1mono // Get rid of all color

twoway /*
    */ (line g_gdp yq,      lpattern(solid) lwidth(medium) lcolor(orange_red)) /*
    */ (line g_l yq,        lpattern(dot) lwidth(thick) lcolor(midblue)) /*
    */ (line g_l_exma yq,   lpattern(dash_dot) lwidth(medium) lcolor(midblue)) /*
    */  /*
    */ , /*
    */ plotr(m(zero)) plotregion(lwidth(vthin)) /* 
    */ aspect(.25) /* 
    */  /*
    */ title(" ", size(medium)) /*
    */  /*
    */ ytitle("Annual Growth Rate (%)", size(vsmall)) /*
    */ yscale(range(-.20 .20) lwidth(vthin)) /*
    */ ylabel(-.20 "-20%" -.15 "-15%"  -.10 "-10%" -.05 "-5%" 0 "0" /*
    */ +.05 "+5%" +.10 "+10%" +.15 "+15%" +.20 "+20%" /*
    */ , labsize(vsmall) angle(horizontal) tlwidth(vthin)) /*
    */  /*
    */  /*
    */ xtitle(" ", size(tiny)) /*
    */ xscale(range(152 215)  lwidth(vthin)) /*
    */ xlabel(153.5 "1998" 161.5 "2000" 169.5 "2002" 177.5 "2004" /*
    */ 185.5 "2006" 193.5 "2008" 201.5 "2010" 209.5 "2012" /*
    */ , labsize(vsmall) noticks) /*
    */  /*
    */ yline(0, lpattern(solid) lcolor(black) lwidth(vthin)) /*
    */ xline(187, lcolor(cranberry) lwidth(vthin) lpattern(dash)) /*
    */  /*
    */ text(.235  187 "War on Drugs Starts in", placement(n) size(vsmall)) /*
    */ text(.21  187 "December, 2006", placement(n) size(vsmall)) /*
    */  /*
    */  /*
    */ legend(on  region(style(none)) /*
    */ bmargin(0 0 0 -4)  /*
    */ rowgap(1) colgap(8) keygap(.5) symxsize(10) symysize(1) size(vsmall) /*
    */ order(1 2 3 )  /*
    */ label(1 "GDP") /*
    */ label(2 "Formal Employment: All") /*
    */ label(3 "Formal Employment: Export Manufacturing Only") /*
    */ row(1) ) 

graph export "$path/Figs/DescStatLine.eps", replace 
graph save Graph "$path/Graph.gph", replace

